@@ -3,9 +3,9 @@ GET_ORG_VISIT_DURATION = """
                 organization: getOrganization(id: $id) {
                 durationOfVisits(
                     from: $from, to: $to) {
-                        hPerDay,
-                        clientCount,
-                        percClient,
+                        visitDuration: hPerDay,
+                        visitsCount: clientCount, 
+                        visitsPct: percClient,
                         countryRegion
                      }
                 }
@@ -17,9 +17,9 @@ GET_ORG_VISIT_FREQ = """
             organization: getOrganization(id: $id) {
             frequencyOfVisits(
                 from: $from, to: $to) {
-                    daysPerWeek,
-                    clientCount,
-                    percClient,
+                    visitFrequency: daysPerWeek,
+                    visitsCount: clientCount,
+                    visitsPerc: percClient,
                     countryRegion
                 }
             }
@@ -198,9 +198,9 @@ GET_LOCATION_VISIT_DURATION = """
                                     from: $from, 
                                     to: $to
                                 ) {
-                                    hoursCount, 
-                                    clientsCount,
-                                    clientsPct
+                                    visitDuration: hoursCount, 
+                                    visitsCount: clientsCount,
+                                    visitsPerc: clientsPct
                                 }
                             }
                         }
@@ -219,9 +219,9 @@ GET_LOCATION_VISIT_FREQ = """
                                     from: $from, 
                                     to: $to
                                 ) {
-                                    daysPerWeek, 
-                                    clientsCount,
-                                    clientsPct
+                                    visitFrequency: daysPerWeek, 
+                                    visitsCount: clientsCount,
+                                    visitsPct: clientsPct
                                 }
                             }
                         }
@@ -281,9 +281,9 @@ GET_LOCATION_POPULAR_VISIT_DAYS = """
                             from: $from, 
                             to: $to
                         ) {
-                            dayOfWeek, 
-                            clientsCount,
-                            clientsPct
+                            visitWeekday: dayOfWeek, 
+                            visitsCount: clientsCount,
+                            visitsPct: clientsPct
                         }
                     }
                 }
@@ -329,9 +329,9 @@ GET_ORG_POPULAR_VISIT_DAYS = """
             query getOrgPopularDaysOfVisits($id: ID, $from: DateTime!, $to: DateTime!){
               organization: getOrganization(id: $id) {
                   popularDaysOfVisits(from: $from, to: $to) { 
-                      dayOfWeek,
-                      clientsCount,
-                      clientsPct,
+                      visitWeekday: dayOfWeek,
+                      visitsCount: clientsCount,
+                      visitsPct: clientsPct,
                       countryRegion
                       }}
         }
